===================================
salt.returners.postgres_local_cache
===================================

.. automodule:: salt.returners.postgres_local_cache
    :members:
    :exclude-members: save_minions
